 # 文件管理工具

## 背景
   现实生活数字化不断深入，电脑中的文件越来越多，照片也越来越多。备份是必须的手段，一旦磁盘损坏，损失无法估算。
   但备份的时候不知道多少文件是备份过的，多少备份过的文件又是更新了的。还有可能很多文件在多个目录中重复存在，浪费很多存储空间。
  本工具就是为了解决这两种情况而编制的。供大家使用。
  



# 主要功能：

1. 文件比较和同步
- 源目的文件夹文件比较，判断文件是否已经同步。
- 根据结果，选择需要同步的文件，快速双向同步。

2. 文件消重
- 发现给定的文件夹下的重复文件；(文件尺寸+修改时间）（文件尺寸+文件时间+md5值）
- 挑选重复文件删除。

3. 文件查找
- 支持正则表达式查找文件名


# Installation and Dependencies

## 具备Python3 运行环境
 如果你已经在电脑上安装了python3，可以直接使用pip3 安装


```
pip3 install windfile
```
## 直接下载可执行文件
	github  https://github.com/gonewind73/FileManage/blob/develop/dist/windfile.exe

## 运行：
```
windfile.bat
```
或者 
```
python -m windfile.fileman_ui
```

## 设置
1. 可以设置最大深度，缺省为10
2. 可以设置文件夹下最大节点数（包括文件夹和文件），缺省为500
3. 可以根据需要设置 当前用户Home目录的.windfile 中 修改 max_depth 和 max_nodes 即可



## 反馈
有使用上问题，请发送邮件给 gonewind08@qq.com 


## 版本更新记录
1.  2022/06/02/  
    1.  Ver 2.0.1 
    2.  修改了配置文件中的Bug，迁移到用户home目录
    3.  修复其他一些问题
2.  2022/05/24/  
    1.  Ver 2.0.0 改写了大部分逻辑，更易使用。
    2.  支持最大深度、最大节点数设置，避免超大文件夹长时间等待。
    3.  
3. 2018年2月6日 v1.3 发布

   1. 
4. 2018年1月15日 版本1.1发布



